mod dto;
mod entity;
mod handler;
mod params;
mod repository;
mod response;
mod routes;
mod service;
mod state;

use crate::state::app::AppState;
use axum::{Server, ServiceExt};
use sea_orm::Database;
use std::env;
use std::sync::Arc;

#[tokio::main]
async fn main() {
    dotenvy::dotenv().ok();
    let db_url = env::var("DATABASE_URL").expect(".env 文件中没有设置 DATABASE_URL");
    let upload_path = env::var("UPLOAD_PATH").expect(".env 文件中没有设置 UPLOAD_PATH");

    let db_conn = Database::connect(&db_url).await.expect("数据库链接失败");

    let app_state = AppState { db_conn, upload_path };

    let app = routes::create_routes(Arc::new(app_state));
    Server::bind(&"0.0.0.0:3000".parse().unwrap())
        .serve(app)
        .await
        .unwrap();
}
